=================================
Getting help on using ``skimage``
=================================

API Reference
-------------

Keep the `reference guide <https://scikit-image.org/docs/stable/>`__
handy while programming with scikit-image.
Select the docs that match the version of skimage you are using.

Examples gallery
----------------

The :ref:`examples_gallery` gallery provides graphical examples and
code snippets of typical image processing tasks. There, you may find
an example that is close to your use case.

Feel free to suggest new gallery examples on our `developer forum
<https://discuss.scientific-python.org/c/contributor/skimage>`__.

Search field
------------

Use the ``quick search`` field in the navigation bar of the online
documentation to find mentions of keywords (segmentation,
rescaling, denoising, etc.) in the documentation.

API Discovery
-------------

We provide a ``lookfor`` function to search API functions::

   import skimage as ski
   ski.lookfor('eigenvector')

Also see NumPy's ``lookfor``.

Ask for help
------------

Still stuck? We are here to help! Reach out through:

- our `user forum <https://forum.image.sc/tags/scikit-image>`_ for
  image processing and usage questions;
- our `developer forum
  <https://discuss.scientific-python.org/c/contributor/skimage>`_
  for technical questions and suggestions;
- our `chat channel <https://skimage.zulipchat.com/>`_ for real-time
  interaction; or
- `Stack Overflow
  <https://stackoverflow.com/questions/tagged/scikit-image>`_ for
  coding questions.
